==> pykawaii-2.8.0-py3-none-any.whl: pykawaii/cache.py <==
"""
MIT License

Copyright (c) 2022 Okimii

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import annotations

from typing import Any


__all__ = ["Cache"]


class Cache:
    def __init__(self, cachable: bool) -> None:
        self.cachable = cachable
        self.cache: list[str] = []

    def __setattr__(self, name: str, value: Any) -> None:
        setattr(self, name, value)

    def __getattribute__(self, name: str) -> Any:
        getattr(self, name)

    
    def getobj(self, index: int) -> str | None:
        if self.cachable:
            return self.cache.get(index)
        return None

    
    def setobj(self, value: str) -> str | None:
        if self.cachable:
            return self.cache.append(value)
        return None

==> pykawaii-3.4.0-py3-none-any.whl: pykawaii/cache.py <==
"""
MIT License

Copyright (c) 2022 Okimii

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import annotations

from typing import Any


__all__ = ["Cache"]


class Cache:

    cache: list[str] = []

    def __setattr__(self, name: str, value: Any) -> None:
        setattr(self, name, value)

    def getobj(self, index: int) -> str | None:
        if self.cachable:
            return self.cache.get(index)
        return None

    
    def setobj(self, value: str) -> str | None:
        if self.cachable:
            return self.cache.append(value)
        return None
